@@ -46,10 +46,12 @@ static const gchar *contributors[] = {
 	"Calum Benson",
 	"Jacob Berkman",
 	"Eckehard Berns",
+	"\xc5\xbdygimantas Beru\xc4\x8dka",
 	"Runa Bhattacharjee",
 	"Robert Bihlmeyer",
 	"Jonathan Blandford",
 	"Christopher Blizzard",
+	"Bruno Boaventura",
 	"\xd0\x95\xd0\xb2\xd0\xb3\xd0\xb5\xd0\xbd\xd0\xb8 \xd0\x91\xd0\xbe\xd0\xb5\xd0\xb2\xd1\x81\xd0\xba\xd0\xb8 (Evgeni Boevski)",
 	"J\xc3\xa9r\xc3\xb4me Bolliet",
 	"Andreas Bolsch",
@@ -166,6 +168,7 @@ static const gchar *contributors[] = {
 	"Tim Gerla",
 	"Bj\xc3\xb6rn Giesler",
 	"Quim Gil",
+	"Evandro Fernandes Giovanini",
 	"\xd0\x92\xd0\xbb\xd0\xb0\xd0\xb4\xd0\xb8\xd0\xbc\xd0\xb8\xd1\x80\xd0\xb0 \xd0\x93\xd0\xb8\xd1\x80\xd0\xb3\xd0\xb8\xd0\xbd\xd0\xbe\xd0\xb2\xd0\xb0 (Vladimira Girginova)",
 	"Dave Glowacki",
 	"Scott Goehring",
@@ -197,6 +200,7 @@ static const gchar *contributors[] = {
 	"James Henstridge",
         "Fernando Herrera",
 	"Richard Hestilow",
+	"Raphael Higino",
 	"Thomas Hinkle",
 	"Iain Holmes",
 	"Adam Hooper",
@@ -231,6 +235,7 @@ static const gchar *contributors[] = {
 	"Matt Keenan",
 	"g\xc3\xa1bor Kelemen",
 	"Michael Kellen",
+	"Christian Kellner",
 	"Stephen Kiernan",
 	"Spencer Kimball",
 	"Christian Kintner",
@@ -245,6 +250,7 @@ static const gchar *contributors[] = {
 	"Martin Kretzschmar",
 	"Harish Krishnaswamy",
 	"Andrew Kuchling",
+	"Tomas Kuliavas",
 	"Stephan Kulow",
 	"Kaushal Kumar",
 	"Nirmal Kumar",
@@ -317,6 +323,7 @@ static const gchar *contributors[] = {
 	"Christophe Merlet",
 	"Christian Meyer",
 	"Tim Miao",
+	"Gintautas Miliauskas",
 	"Cesar Miquel",
 	"Julian Missig",
 	"Eric B. Mitchell",
@@ -467,6 +474,7 @@ static const gchar *contributors[] = {
 	"Ben Stern",
 	"Micah Stetson",
 	"Ray Strode",
+	"Luke Stroven",
 	"Mariano Su\xc3\xa1rez-Alvarez",
 	"Parthasarathi Susarla",
 	"Nathan Carl Summers",
